@@ -1,163 +1,5 @@
 r'''
-# aws-lambda-sqs-lambda module
-
-<!--BEGIN STABILITY BANNER-->---
-
-
-![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
-
-> All classes are under active development and subject to non-backward compatible changes or removal in any
-> future version. These are not subject to the [Semantic Versioning](https://semver.org/) model.
-> This means that while you may use them, you may need to update your source code when upgrading to a newer version of this package.
-
----
-<!--END STABILITY BANNER-->
-
-| **Reference Documentation**:| <span style="font-weight: normal">https://docs.aws.amazon.com/solutions/latest/constructs/</span>|
-|:-------------|:-------------|
-
-<div style="height:8px"></div>
-
-| **Language**     | **Package**        |
-|:-------------|-----------------|
-|![Python Logo](https://docs.aws.amazon.com/cdk/api/latest/img/python32.png) Python|`aws_solutions_constructs.aws_lambda_sqs_lambda`|
-|![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-lambda-sqs-lambda`|
-|![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.lambdasqslambda`|
-
-## Overview
-
-This AWS Solutions Construct implements (1) an AWS Lambda function that is configured to send messages to a queue; (2) an Amazon SQS queue; and (3) an AWS Lambda function configured to consume messages from the queue.
-
-Here is a minimal deployable pattern definition:
-
-Typescript
-
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { LambdaToSqsToLambda, LambdaToSqsToLambdaProps } from "@aws-solutions-constructs/aws-lambda-sqs-lambda";
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-
-new LambdaToSqsToLambda(this, 'LambdaToSqsToLambdaPattern', {
-  producerLambdaFunctionProps: {
-      runtime: lambda.Runtime.NODEJS_16_X,
-      handler: 'index.handler',
-      code: lambda.Code.fromAsset(`producer-lambda`)
-  },
-  consumerLambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_16_X,
-    handler: 'index.handler',
-    code: lambda.Code.fromAsset(`consumer-lambda`)
-  }
-});
-```
-
-Python
-
-```python
-from aws_solutions_constructs.aws_lambda_sqs_lambda import LambdaToSqsToLambda
-from aws_cdk import (
-    aws_lambda as _lambda,
-    Stack
-)
-from constructs import Construct
-
-LambdaToSqsToLambda(
-    self, 'LambdaToSqsToLambdaPattern',
-    producer_lambda_function_props=_lambda.FunctionProps(
-        code=_lambda.Code.from_asset('producer_lambda'),
-        runtime=_lambda.Runtime.PYTHON_3_9,
-        handler='index.handler'
-    ),
-    consumer_lambda_function_props=_lambda.FunctionProps(
-        code=_lambda.Code.from_asset('consumer_lambda'),
-        runtime=_lambda.Runtime.PYTHON_3_9,
-        handler='index.handler'
-    )
-)
-```
-
-Java
-
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.lambdasqslambda.*;
-
-new LambdaToSqsToLambda(this, "LambdaToSqsToLambdaPattern", new LambdaToSqsToLambdaProps.Builder()
-        .producerLambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_16_X)
-                .code(Code.fromAsset("producer-lambda"))
-                .handler("index.handler")
-                .build())
-        .consumerLambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_16_X)
-                .code(Code.fromAsset("consumer-lambda"))
-                .handler("index.handler")
-                .build())
-        .build());
-```
-
-## Pattern Construct Props
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|existingProducerLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|An optional, existing Lambda function to be used instead of the default function for sending messages to the queue. Providing both this and `producerLambdaFunctionProps` will cause an error. |
-|producerLambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|Optional user-provided properties to override the default properties for the producer Lambda function. |
-|existingQueueObj?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|An optional, existing SQS queue to be used instead of the default queue. Providing both this and `queueProps` will cause an error.|
-|queueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.QueueProps.html)|Optional user-provided properties to override the default properties for the SQS queue. Providing both this and `existingQueueObj` will cause an error. |
-|deployDeadLetterQueue?|`boolean`|Whether to create a secondary queue to be used as a dead letter queue. Defaults to `true`.|
-|deadLetterQueueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.QueueProps.html)|Optional user-provided props to override the default props for the dead letter queue. Only used if the `deployDeadLetterQueue` property is set to `true`.|
-|maxReceiveCount?|`number`|The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to `15`.|
-|existingConsumerLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|An optional, existing Lambda function to be used instead of the default function for receiving/consuming messages from the queue. Providing both this and `consumerLambdaFunctionProps` will cause an error. |
-|consumerLambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|Optional user-provided properties to override the default properties for the consumer Lambda function.|
-|queueEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the URL of the queue. Default: SQS_QUEUE_URL |
-|sqsEventSourceProps?| [`SqsEventSourceProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda_event_sources.SqsEventSourceProps.html)|Optional user provided properties for the queue event source.|
-|existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon SQS. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
-|vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overridden. If `deployVpc` is not `true` then this property will be ignored.|
-|deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
-
-## Pattern Properties
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|producerLambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Returns an instance of the producer Lambda function created by the pattern.|
-|sqsQueue|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|Returns an instance of the SQS queue created by the pattern. |
-|deadLetterQueue?|[`sqs.Queue \| undefined`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|Returns an instance of the dead letter queue created by the pattern, if one is deployed.|
-|consumerLambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Returns an instance of the consumer Lambda function created by the pattern.|
-|vpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|Returns an interface on the VPC used by the pattern (if any). This may be a VPC created by the pattern or the VPC supplied to the pattern constructor.|
-
-## Default Settings
-
-Out-of-the-box implementation of this Construct (without any overridden properties) will adhere to the following defaults:
-
-### AWS Lambda Functions
-
-* Configure limited privilege access IAM role for Lambda functions.
-* Enable reusing connections with Keep-Alive for NodeJs Lambda functions.
-* Enable X-Ray Tracing
-* Set Environment Variables
-
-  * AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
-
-### Amazon SQS Queue
-
-* Deploy a dead letter queue for the primary queue.
-* Enable server-side encryption for the primary queue using an AWS Managed KMS Key.
-* Enforce encryption of data in transit
-
-## Architecture
-
-![Architecture Diagram](architecture.png)
-
----
-
-
-© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+Documentation for this pattern can be found [here](https://github.com/awslabs/aws-solutions-constructs/blob/main/source/patterns/%40aws-solutions-constructs/aws-lambda-sqs-lambda/README.adoc)
 '''
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
@@ -230,7 +72,7 @@ class LambdaToSqsToLambda(
         '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param consumer_lambda_function_props: Optional user-provided properties to override the default properties for the consumer Lambda function. Default: - Default properties are used.
+        :param consumer_lambda_function_props: Optional - user provided props to override the default props for the consumer Lambda function. Providing both this and ``existingConsumerLambdaObj`` is an error. Default: - Default properties are used.
         :param dead_letter_queue_props: Optional user-provided props to override the default props for the dead letter queue. Only used if the ``deployDeadLetterQueue`` property is set to true. Default: - Default props are used.
         :param deploy_dead_letter_queue: Whether to create a secondary queue to be used as a dead letter queue. Defaults to ``true``. Default: - true.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -239,9 +81,9 @@ class LambdaToSqsToLambda(
         :param existing_queue_obj: An optional, existing SQS queue to be used instead of the default queue. Providing both this and ``queueProps`` will cause an error. Default: - None.
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to ``15``. Default: - 15.
-        :param producer_lambda_function_props: Optional user-provided properties to override the default properties for the producer Lambda function. Default: - Default properties are used.
+        :param producer_lambda_function_props: Optional - user provided props to override the default props for the producer Lambda function. Providing both this and ``existingProducerLambdaObj`` is an error. Default: - Default properties are used.
         :param queue_environment_variable_name: Optional Name for the Lambda function environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
-        :param queue_props: Optional user-provided properties to override the default properties for the SQS queue. Default: - Default props are used.
+        :param queue_props: Optional - user provided properties to override the default properties for the SQS queue. Providing both this and ``existingQueueObj`` will cause an error. Default: - Default props are used.
         :param sqs_event_source_props: Optional user provided properties for the queue event source. Default: - Default props are used
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
@@ -339,7 +181,7 @@ class LambdaToSqsToLambdaProps:
         vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
-        :param consumer_lambda_function_props: Optional user-provided properties to override the default properties for the consumer Lambda function. Default: - Default properties are used.
+        :param consumer_lambda_function_props: Optional - user provided props to override the default props for the consumer Lambda function. Providing both this and ``existingConsumerLambdaObj`` is an error. Default: - Default properties are used.
         :param dead_letter_queue_props: Optional user-provided props to override the default props for the dead letter queue. Only used if the ``deployDeadLetterQueue`` property is set to true. Default: - Default props are used.
         :param deploy_dead_letter_queue: Whether to create a secondary queue to be used as a dead letter queue. Defaults to ``true``. Default: - true.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -348,9 +190,9 @@ class LambdaToSqsToLambdaProps:
         :param existing_queue_obj: An optional, existing SQS queue to be used instead of the default queue. Providing both this and ``queueProps`` will cause an error. Default: - None.
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to ``15``. Default: - 15.
-        :param producer_lambda_function_props: Optional user-provided properties to override the default properties for the producer Lambda function. Default: - Default properties are used.
+        :param producer_lambda_function_props: Optional - user provided props to override the default props for the producer Lambda function. Providing both this and ``existingProducerLambdaObj`` is an error. Default: - Default properties are used.
         :param queue_environment_variable_name: Optional Name for the Lambda function environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
-        :param queue_props: Optional user-provided properties to override the default properties for the SQS queue. Default: - Default props are used.
+        :param queue_props: Optional - user provided properties to override the default properties for the SQS queue. Providing both this and ``existingQueueObj`` will cause an error. Default: - Default props are used.
         :param sqs_event_source_props: Optional user provided properties for the queue event source. Default: - Default props are used
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
@@ -418,7 +260,9 @@ class LambdaToSqsToLambdaProps:
     def consumer_lambda_function_props(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
-        '''Optional user-provided properties to override the default properties for the consumer Lambda function.
+        '''Optional - user provided props to override the default props for the consumer Lambda function.
+
+        Providing both this and ``existingConsumerLambdaObj`` is an error.
 
         :default: - Default properties are used.
         '''
@@ -521,7 +365,10 @@ class LambdaToSqsToLambdaProps:
     def producer_lambda_function_props(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
-        '''Optional user-provided properties to override the default properties for the producer Lambda function.
+        '''Optional - user provided props to override the default props for the producer Lambda function.
+
+        Providing
+        both this and ``existingProducerLambdaObj`` is an error.
 
         :default: - Default properties are used.
         '''
@@ -539,7 +386,9 @@ class LambdaToSqsToLambdaProps:
 
     @builtins.property
     def queue_props(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
-        '''Optional user-provided properties to override the default properties for the SQS queue.
+        '''Optional - user provided properties to override the default properties for the SQS queue.
+
+        Providing both this and ``existingQueueObj`` will cause an error.
 
         :default: - Default props are used.
         '''
